# How it works?

When making changes to configuration files inside distro, it is not really possible
to track them, when they are merged with config_distro module. Although the log entry
is made in watchdog, but it is not enough.

It was decided to create update hook for every change. Also using checklistapi it is
possible to visualise the updates list. It is available here `/admin/reports/checklistapi/update-helper`.
Every time when the updates run in Drupal, a new entry of Update entity type is written
into the database and into this checklist.

To provide meaningful information about what was done, the documentation block should
follow the structure:

```
/**
 * Remove Yoast field from the form display of event content type.
 *
 * The field needs to be removed, because it has problems with ajax subforms,
 * and that is why some paragraphs could not be saved.
 *
 * @success The field was removed successfully.
 * @failure The field was not removed. Please try to move it yourself <a href="/admin/structure/types/manage/event/form-display">here</a>.
 */
 ```

 1. The first line would be a title in the list.
 2. The rest is a description.
 3. Under @success tag you need to write the successful update message.
 4. Under @failure write how to manually do the update. Preferably with the link to the page when it could done.

 ```
 function xi_event_update_8004() {
   /** @var \Drupal\Core\Entity\Display\EntityFormDisplayInterface $form_display */
   $form_display = \Drupal::entityTypeManager()
     ->getStorage('entity_form_display')
     ->load('node.event.default');
   // If we are actually running the update.
   if (\Drupal::state()->get('system.maintenance_mode')) {
     $form_display->removeComponent('field_yoast');
     $form_display->save();
   } else {
     // We are performing the update status check.
     $field_yoast = $form_display->getComponent('field_yoast');
     // Check if the field is still in form display.
     if (empty($field_yoast)) {
       // Update was successful.
       return TRUE;
     } else {
       // Update failed.
       return FALSE;
     }
   }
 }
 ```

Inside update function it is important to separate real update and the check of the status. This is done by
checking if the site is in "maintenance mode" with this condition:
 `\Drupal::state()->get('system.maintenance_mode')`. If it is TRUE then the updates are running at the moment.
If not this function is called to check the status, so it is important to return **boolean** value. In this
part do the checks of whether the update did what it was supposed to. If the check returns true, the Update entity
is marked as successful and checklistapi is updated too. In admin UI you will see the status of the update with
success message and checked item.

Every update hook that has `@success` and `@failure` tags in function description will be registered automatically.

## Commands

To check the status of updates one needs to run following drush command:

`drush xi-updater:check-updates`

Also the check is done automatically after `cd-update` drush command.

# Manual check

If the checkbox is checked manually in the list of updates the update is marked as successful but additional check
is run and in case of failure the message is shown to the user.
