<?php

namespace Drupal\xi_updater\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;

/**
 * Interface for the Update entity.
 */
interface UpdateInterface extends ContentEntityInterface, EntityChangedInterface {

  /**
   * Returns if an update was successful during update hook.
   *
   * @return bool
   *   Update was successful or not.
   */
  public function wasSuccessful();

  /**
   * Set successful_by_hook field value.
   *
   * @param bool $success
   *   Update was successful or not.
   *
   * @return mixed
   *   This object.
   */
  public function setSuccessful($success);

  /**
   * Returns the module name of the update.
   *
   * @return string
   *   Module machine name.
   */
  public function getModuleName();

  /**
   * Returns the update number.
   *
   * @return int
   *   Module update number.
   */
  public function getNumber();

  /**
   * Returns update description.
   *
   * @return string
   *   The description of the update taken from document block
   *   of update function.
   */
  public function getDescription();

}
